/*
    SPDX-FileCopyrightText: 2013-2014 Jan Grulich <jgrulich@redhat.com>
    SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

import QtQuick 2.15
import QtQuick.Layouts 1.15

import org.kde.plasma.components 3.0 as PlasmaComponents3
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.extras 2.0 as PlasmaExtras
import org.kde.plasma.plasmoid 2.0
import org.kde.plasma.private.bluetooth 1.0 as PlasmaBt

import org.kde.kquickcontrolsaddons 2.0

PlasmaExtras.PlasmoidHeading {
    id: toolbar

    readonly property var appletInterface: Plasmoid.self
    property alias checkbox: checkbox

    //leftPadding: mirrored ? 0 : PlasmaCore.Units.smallSpacing
    //rightPadding: mirrored ? PlasmaCore.Units.smallSpacing : 0

    contentItem: ColumnLayout {
        anchors {
            fill: parent
            leftMargin: PlasmaCore.Units.largeSpacing - 4
            rightMargin: PlasmaCore.Units.largeSpacing - 4
        }

        RowLayout {
            Layout.topMargin: 5
            Layout.bottomMargin: 5

            spacing: PlasmaCore.Units.smallSpacing

            PlasmaComponents3.ToolButton {
                icon.name: "preferences-system-bluetooth"
                visible: false // 与UI设计保持一致，暂不显示蓝牙图标
                display: PlasmaComponents3.AbstractButton.IconOnly
                text: i18n("Bluetooth")

                PlasmaComponents3.ToolTip {
                    text: parent.text
                }
            }

            PlasmaExtras.Heading {
                Layout.fillWidth: true
                leftPadding: 0
                font.pointSize: 11
                font.weight: Font.Light
                text: appletInterface.title
            }

            PlasmaComponents3.ToolButton {
                icon.name: "appletSettings"
                display: PlasmaComponents3.AbstractButton.IconOnly
                text: appletInterface.action("configure").text

                PlasmaComponents3.ToolTip {
                    text: parent.text
                }
                
                onClicked: action_configure()
            }

            PlasmaComponents3.CheckBox {
                id: checkbox
                visible: false
                text: i18n("Enable Bluetooth")
                icon.name: "preferences-system-bluetooth"
                checked: btManager.bluetoothOperational
                enabled: btManager.bluetoothBlocked || btManager.adapters.length > 0
                focus: Plasmoid.expanded
                onToggled: toggleBluetooth()
            }

            Item {
                visible: false
                Layout.fillWidth: true
            }

            PlasmaComponents3.ToolButton {
                id: addDeviceButton

                property QtObject /*QAction*/ qAction: Plasmoid.action("addNewDevice")

                //visible: !(Plasmoid.containmentDisplayHints & PlasmaCore.Types.ContainmentDrawsPlasmoidHeading)
                visible: false
                enabled: qAction.visible

                icon.name: "list-add"

                onClicked: qAction.trigger()

                PlasmaComponents3.ToolTip {
                    text: addDeviceButton.qAction.text
                }
                Accessible.name: qAction.text
            }

            PlasmaComponents3.ToolButton {
                id: openSettingsButton

                property QtObject /*QAction*/ qAction: Plasmoid.action("configure")

                //visible: !(Plasmoid.containmentDisplayHints & PlasmaCore.Types.ContainmentDrawsPlasmoidHeading)
                visible: false
                icon.name: "configure"
                onClicked: qAction.trigger()

                PlasmaComponents3.ToolTip {
                    text: openSettingsButton.qAction.text
                }
                Accessible.name: qAction.text
            }
        }
    }
}
